# Writing guidelines for content editors

We're happy for everyone helping us improving the ECA Guide. You can apply to join this project once you've registered
on this platform and then you can contribute to issues and content. Content contributions should be proposed as merge
requests and will go through a review process by one or many others.

Below, we're providing guidelines for writing content, so that we can keep it consistent.

## General

The ECA Guide is completely written in markdown. The framework to generate the published guide is
[MkDocs](https://www.mkdocs.org) and writing content is described in their
[Writing with Markdown](https://www.mkdocs.org/user-guide/writing-your-docs/#writing-with-markdown) section.

### Language

ECA Guide is written in British English.

### Inline code, directories and files names

Those need to be wrapped by single backtick characters.

### Code blocks

A code block is wrapped with 3 backtick characters, each of which on their own line and the block needs to be
preceded and succeeded with a blank line. The language of the code block can be provided following the opening
3 backtick characters on the same line. See also some [examples](https://www.mkdocs.org/user-guide/writing-your-docs/#fenced-code-blocks).

### Links

Links are provided as standard markdown links, e.g. `[link text](url)`. A very common link type in this guide are
internal links, i.e. from some guide content to another page in this guide. Those links get relative URLs, where the
content in the `docs/` directory is the root of the published guide. So if you wanted to link to the usage page in the
ECA section, the URL must be `/eca/usage`.

When linking to the index of a section, e.g. the ECA concepts, then use `/eca/concepts` as the URL, i.e. omitting the
index filename.

### Admonitions

To include notes, infos, tips or other text blocks that should be highlighted, use admonitions, their usage is
[documented](https://squidfunk.github.io/mkdocs-material/reference/admonitions/#usage) and our theme
[supports various types](https://squidfunk.github.io/mkdocs-material/reference/admonitions/#supported-types).

## Plugins

All the files in the `docs/plugins` directory get created and updated automatically. They should never be manually
edited, because those changes would be lost after the next auto update.

Each file in the plugin section contains several include-instructions for files in the directories `include/modules`,
`include/plugins` and `include/fields` where extra content for modules, plugins and fields can be added.

A special note about files in the `include/fields` directory: like for all other include files, regular markdown can
be used with the first paragraph not being indented. However, as the fields documentation is being done with definition
lists, subsequent paragraphs need to be indented with 4 leading space characters.

## Library

All the files in the `docs/library` directory get created and updated automatically. They should never be manually
edited, because those changes would be lost after the next auto update.

To add a new model to the library, open an issue to describe the purpose of the model and upload the exported model
as an attachment. After a review, we will then add new models to the process which updates that section automatically.
